@@ -38,7 +38,9 @@ $LSPCI -n | grep "0300: " | cut -d ' ' -f 1 > /tmp/videolist.tmp
 $LSPCI | grep "VGA"  >>  $logfile
 
 while read VIDEOENTRY; do
-	if [ $BUSID_LEN -lt 12 ]; then  # 00:00.0 type
+	if $LSPCI | grep "0300:" > /dev/null 2>&1; then
+		echo "Unkown video card found" >> /tmp/sysinfo.tmp
+	elif [ $BUSID_LEN -lt 12 ]; then  # 00:00.0 type
 		$LSPCI | grep $VIDEOENTRY | cut -d ':' -f 3 >> /tmp/sysinfo.tmp
 	else 							# 0000:00:00.0 type
 		$LSPCI | grep $VIDEOENTRY | cut -d ':' -f 4 >> /tmp/sysinfo.tmp
