@@ -10,11 +10,12 @@
 #
 #
 logfile="/var/log/userful-start.log"
+ProgramName=`basename $0`
 
-echo "(II) Load userful keymap: /opt/userful/bin/userful.keymap" >>  $logfile
 # load userful.keymap (disable kernel keyboard)
-loadkeys /opt/userful/bin/userful.keymap 2>> /var/log/usbinput.log
+echo "`date +"%b %d %T"` $ProgramName: Load Userful keymap: /opt/userful/bin/userful.keymap" >>  $logfile
+loadkeys /opt/userful/bin/userful.keymap 2>> $logfile
 
-echo "(II) Disable VT change" >>  $logfile
 # Disable VT change
+echo "`date +"%b %d %T"` $ProgramName: Disable VT change" >>  $logfile
 /opt/userful/bin/vtlock -enable
