@@ -18,13 +18,17 @@ if [ ! -f /etc/userful/os-info ]; then
 	/opt/userful/bin/dm-check-os.sh
 fi
 source /etc/userful/os-info
-source /etc/userful/Userful-supported-distro
+source /etc/userful/userful-supported-distros
 
 case "$OSNAME" in
 	fedora)
 		SUPPORTED_VER=$FEDORA
 		;;
 
+	freedows)
+		SUPPORTED_VER=$FREEDOWS
+		;;
+
 	novell)
 		SUPPORTED_VER=$NOVELL
 		;;
@@ -55,10 +59,18 @@ case "$OSNAME" in
 		SUPPORTED_VER=$XANDROS
 		;;
 
+	morphix)
+		SUPPORTED_VER=$MORPHIX
+		;;
+
 	ubuntu)
 		SUPPORTED_VER=$UBUNTU
 		;;
 	
+	freespire)
+		SUPPORTED_VER=$FREESPIRE
+		;;
+
 	linspire)
 		SUPPORTED_VER=$LINSPIRE
 		SUPPORTED_OS=$TRUE
