@@ -8,16 +8,18 @@
 # generate config file for 1Box-Server.
 #########################
 
-MAXSCREEN=10
+logfile="/var/log/userful-start.log"
+ProgramName=`basename $0`
+
+source /opt/userful/bin/userful-bash-lib.sh
+
 MXDEVNO=0 # For Multi X configuration
 SXDEVNO=0 # For Normal X configuration
 HEADNO=
 NUM_OF_HEAD=
 CURR_CARD_TYPE=
-NVIDIA_DRIVER=
 
-# upto ten station for now
-STATION_TYPE=( S S S S S S S S S S )
+STATION_TYPE=
 
 SUCCESS=0
 
@@ -39,6 +41,12 @@ MODES=
 
 DISABLEXVIDMODE=0
 
+# error-out function
+bomb() {
+	echo "$PROGRAM_NAME: error: $*" >> $logfile
+	exit 1
+}
+
 # set LSPCI
 if which lspci > /dev/null 2>&1; then
 	LSPCI="lspci"
@@ -73,23 +81,28 @@ gen_Header()
 # $1: config type
 gen_Files()
 {
+	if [ -f /etc/userful/MXVERSION ]; then
+		source /etc/userful/MXVERSION
+	else
+		MXVER=MX11R6
+	fi
+
 	echo '
 Section "Files"
 	RgbPath		"/usr/X11R6/lib/X11/rgb"' >> tmpconfig
 
 	if [ "$1" == "-1box" ] || [ "$1" == "-ds" ]; then
-		if [ -d /opt/MX11R6/lib64/modules ]; then
-			echo '	ModulePath	"/opt/MX11R6/lib64/modules"' >> tmpconfig
+		if [ "$MXVER" == "MX11R6" ]; then
+			echo '	ModulePath	"/opt/MX11R6/'$LIB'/modules"' >> tmpconfig
+		else
+			echo '	ModulePath	"/opt/MX11R7/lib/xorg/modules"' >> tmpconfig
 		fi
-		echo '	ModulePath	"/opt/MX11R6/lib/modules"' >> tmpconfig
 	fi
 
-	if [ -d /usr/X11R6/lib64/modules ]; then
-    	echo '	ModulePath	"/usr/X11R6/lib64/modules"' >> tmpconfig
-	fi
-    echo '	ModulePath	"/usr/X11R6/lib/modules"
-	FontPath	"unix/:7100"
-	FontPath	"/usr/X11R6/lib/X11/fonts/local/"
+	if [ "$MXVER" == "MX11R6" ]; then
+		echo '	ModulePath	"/usr/X11R6/'$LIB'/modules"
+    FontPath	"unix/:7100"
+    FontPath	"/usr/X11R6/lib/X11/fonts/local/"
 	FontPath	"/usr/X11R6/lib/X11/fonts/misc/"
 	FontPath	"/usr/X11R6/lib/X11/fonts/75dpi/:unscaled"
 	FontPath	"/usr/X11R6/lib/X11/fonts/100dpi/:unscaled"
@@ -99,6 +112,21 @@ Section "Files"
 	FontPath	"/usr/X11R6/lib/X11/fonts/75dpi/"
 	FontPath	"/usr/X11R6/lib/X11/fonts/100dpi/"
 EndSection' >> tmpconfig
+
+	else
+		echo '	ModulePath	"/usr/'$LIB'/xorg/modules"
+    FontPath	"unix/:7100"
+    FontPath	"/opt/MX11R7/share/X11/fonts/local/"
+    FontPath	"/opt/MX11R7/share/X11/fonts/misc/"
+    FontPath	"/opt/MX11R7/share/X11/fonts/75dpi/:unscaled"
+    FontPath	"/opt/MX11R7/share/X11/fonts/100dpi/:unscaled"
+    FontPath	"/opt/MX11R7/share/X11/fonts/Type1/"
+    FontPath	"/opt/MX11R7/share/X11/fonts/CID/"
+    FontPath	"/opt/MX11R7/share/X11/fonts/Speedo/"
+    FontPath	"/opt/MX11R7/share/X11/fonts/75dpi/"
+    FontPath	"/opt/MX11R7/share/X11/fonts/100dpi/"
+EndSection' >> tmpconfig
+	fi
 }
 
 #
@@ -137,6 +165,39 @@ Section "Module"
 EndSection' >> tmpconfig
 }
 
+# wrapper around db_get
+fetch()
+{
+	FETCH_VAL=""
+	db_get $DB_PATH$1
+	if [ $? -eq 0 -a -n "$RET" ]; then
+		FETCH_VAL="$RET"
+	fi
+
+	if [ -z "$FETCH_VAL" ]; then
+		case "$1" in
+			rules)
+				FETCH_VAL="xorg"
+				;;
+			layout)
+				FETCH_VAL="us"
+				;;
+			model)
+				FETCH_VAL="pc105"
+				;;
+			variant)
+				FETCH_VAL="NULL"
+				;;
+			options)
+				FETCH_VAL="NULL"
+				;;
+			*)
+				bomb "Invalid argument for db_get."
+				;;
+		esac
+	fi
+}
+
 #
 # InputDevice section for Keyboard
 # $1: config type 
@@ -145,9 +206,12 @@ gen_InputDevice_kbd()
 {
 	if [ -f /usr/X11R6/bin/Xorg ]; then
 		XKBRULES="xorg"
-	else
+	elif [ -f /usr/X11R6/bin/XFree86 ]; then
 		XKBRULES="xfree86"
+	else
+		XKBRULES="xorg"
 	fi
+
 	if [ -f /etc/sysconfig/keyboard ]; then
 		source /etc/sysconfig/keyboard
 
@@ -157,6 +221,85 @@ gen_InputDevice_kbd()
 		XKBMODEL=`echo $XKBSTRING | awk -F'^' '{printf $3}'`
 		XKBVARIANT=`echo $XKBSTRING | awk -F'^' '{printf $4}'`
 		XKBOPTIONS=`echo $XKBSTRING | awk -F'^' '{printf $5}'`
+
+	elif which dexconf > /dev/null 2>&1; then
+		. /usr/share/debconf/confmodule
+		DB_PATH="xserver-xorg/config/inputdevice/keyboard/"
+
+		# need to check xorg.conf file first
+		if [ -f /etc/X11/xorg.conf ]; then
+
+			# XKBRULES
+			XKBVAL=`grep "XkbRules" /etc/X11/xorg.conf | awk -- '{print $3}' | tr -d \"`
+			if [ -n "$XKBVAL" ]; then
+				XKBRULES="$XKBVAL"
+			else
+				fetch rules
+				XKBRULES="$FETCH_VAL"
+			fi
+
+			# XKBLAYOUT
+			XKBVAL=`grep "XkbLayout" /etc/X11/xorg.conf | awk -- '{print $3}' | tr -d \"`
+			if [ -n "$XKBVAL" ]; then
+				XKBLAYOUT="$XKBVAL"
+			else
+				fetch layout
+				XKBLAYOUT="$FETCH_VAL"
+			fi
+
+			# XKBMODEL
+			XKBVAL=`grep "XkbModel" /etc/X11/xorg.conf | awk -- '{print $3}' | tr -d \"`
+			if [ -n "$XKBVAL" ]; then
+				XKBMODEL="$XKBVAL"
+			else
+				fetch model
+				XKBMODEL="$FETCH_VAL"
+			fi
+
+			# XKBVARIANT
+			XKBVAL=`grep "XkbVariant" /etc/X11/xorg.conf | awk -- '{print $3}' | tr -d \"`
+			if [ -n "$XKBVAL" ]; then
+				XKBVARIANT="$XKBVAL"
+			else
+				fetch variant
+				XKBVARIANT="$FETCH_VAL"
+			fi
+
+			# XKBOPTIONS
+			XKBVAL=`grep "XkbOptions" /etc/X11/xorg.conf | awk -- '{print $3}' | tr -d \"`
+			if [ -n "$XKBVAL" ]; then
+				XKBOPTIONS="$XKBVAL"
+			else
+				fetch options
+				XKBOPTIONS="$FETCH_VAL"
+			fi
+
+		else
+			for ARG in rules layout model variant options; do
+				fetch $ARG
+				case "$ARG" in
+					rules)
+						XKBRULES="$FETCH_VAL"
+						;;
+					layout)
+						XKBLAYOUT="$FETCH_VAL"
+						;;
+					model)
+						XKBMODEL="$FETCH_VAL"
+						;;
+					variant)
+						XKBVARIANT="$FETCH_VAL"
+						;;
+					options)
+						XKBOPTIONS="$FETCH_VAL"
+						;;
+					*)
+						bomb "Invalid argument for db_get."
+						;;
+				esac
+			done
+
+		fi
 	else
 		XKBLAYOUT="us"
 		XKBMODEL="pc105"
@@ -690,7 +833,7 @@ EndSection' >> tmpconfig
 			radeon_multihead_config $1
 			;;
 		
-    		nv)
+    		nv|nvidia)
 			nvidia_multihead_config $1
 			;;
 
@@ -946,7 +1089,7 @@ gen_Device()
 		get_card_value $1 "$VIDEOCARD"
 
 		if [ "$1" == "-1box" ]; then
-			if [ "$DRIVER" == "nv" -a $NVIDIA_DRIVER -eq 0 ]; then
+            if [ "$DRIVER" == "nv" -a "$IS_NVIDIA_DRIVER" == "false" ]; then
 				HEADNO=1
 			elif [ $SYS_DUALVIEW -gt 0 ]; then
 				if grep "$DEVID" /opt/userful/bin/VGAINFO > /dev/null ; then
@@ -987,7 +1130,7 @@ gen_Device()
 				echo "Found in VGAINFO = $VENDORID:$VIDEOID"
 				HEADNO=`grep "$VENDORID:$VIDEOID" /opt/userful/bin/VGAINFO | awk -- '{print $2}'`
 				echo "$BUSID^$VENDORNAME^$BOARDNAME^$DRIVER^$HEADNO^$VENDORID:$VIDEOID" >> /etc/mvgainfo
-			elif [ "$DRIVER" == "nv" -a $NVIDIA_DRIVER -eq 0 ]; then
+            elif [ "$DRIVER" == "nv" -a "$IS_NVIDIA_DRIVER" == "false" ]; then
 				echo "There is no nvidia driver."
 				HEADNO=1
 				echo "$BUSID^$VENDORNAME^$BOARDNAME^$DRIVER^$HEADNO^$VENDORID:$VIDEOID" >> /etc/mvgainfo
@@ -1062,30 +1205,72 @@ usage()
 	exit 0
 }
 
+#-------------------------------
+# start here...
+#-------------------------------
+echo "`date +"%b %d %T"` $ProgramName: $ProgramName $1" >> $logfile
+
+###########################
+# Check arguments recieved
+###########################
 if [ $# != 1 ]; then
 	usage $0
 fi
-
 if [ "$1" != "-1box" ] && [ "$1" != "-ds" ] && [ "$1" != "-check" ] && \
 	[ "$1" != "-one" ] && [ "$1" != "-all" ]; then
 	usage $0
 fi
 
-#
-# start...
+####################################
+# Check system type (32bit or 64bit)
+####################################
+LIB=$(Check_System_Type)
+
+####################
+# Check MAXSTATIONS
+####################
+if [ -e /etc/userful/dm-max-stations ]; then
+    source /etc/userful/dm-max-stations
+else
+	echo "`date +"%b %d %T"` $ProgramName: /etc/userful/dm-max-stations doesn't exist" >> $logfile
+    exit 1
+fi
+
+# Initialize STATION_TYPE array based on MAXSTATIONS
+for (( i=0; i<$MAXSTATIONS; i++ )); do
+	STATION_TYPE[$i]=S
+done
+
+####################################################################
+# Check os-info and dm-sys-info
+#  - dm-sys-info : generated by config-message (Press Enter program)
+####################################################################
+if [ -f /etc/userful/os-info ]; then
+	source /etc/userful/os-info
+else
+	echo "`date +"%b %d %T"` $ProgramName: /etc/userful/os-info is not available" >> $logfile
+	exit 1
+fi
+
 if [ -f /etc/dm-sys-info ]; then
 	source /etc/dm-sys-info
 else
+    if [ "$1" == "-1box" ]; then
+        echo "`date +"%b %d %T"` $ProgramName: /etc/dm-sys-info is not available. Use default values." >> $logfile
+    fi
 	SYS_TYPE=0
 	SYS_RESOLUTION=3
 	SYS_DUALVIEW=0
 fi
 
-if [ -f /usr/X11R6/lib/modules/drivers/nvidia_drv.o -o \
-	 -f /usr/X11R6/lib64/modules/drivers/nvidia_drv.o ]; then
-	NVIDIA_DRIVER=1  #exist
-else
-	NVIDIA_DRIVER=0
+#####################################################
+# check if the nVidia driver and kernel module exist.
+#####################################################
+if $LSPCI -n | tr "a-z" "A-Z" | grep "0300:[[:space:]]10DE:" > /dev/null 2>&1 ; then
+    IS_NVIDIA_DRIVER=$(Check_nVidia_Driver)
+    if [ "$IS_NVIDIA_DRIVER" == "false" ]; then
+        echo "`date +"%b %d %T"` $ProgramName: nVidia driver and/or kernel module was not found." >> $logfile
+    fi
 fi
 
 gen_Header $1
