@@ -10,7 +10,10 @@
 #
 ###################################################################################
 
-logfile="/var/log/usbinput.log"
+logfile="/var/log/userful-start.log"
+usbinput_logfile="/var/log/usbinput.log"
+ProgramName=`basename $0`
+LOCK_FILE="/tmp/usbinput.lock"
 PHYS=
 
 if [ ! -e /var/run/x.pid -o ! -d /proc/`cat /var/run/x.pid` ]; then
@@ -29,12 +32,29 @@ fi
 # remove " from the $1
 PHYS=`echo $1 | tr -d "\""`
 
-date >> $logfile
-echo "New Device: $PHYS" >> $logfile
+echo "`date +"%b %d %T"` $ProgramName: Add new device $PHYS" >> $usbinput_logfile
+echo "`date +"%b %d %T"` $ProgramName: Add new device $PHYS" >> $logfile
+
+##
+## /etc/usbinput should be accessed exclusively.
+while ! (set -C; : > $LOCK_FILE) 2> /dev/null; do
+	usleep 200000
+done
+
+# Check the device config type.  If it is static, use static configration.
+source /etc/userful/dm.conf
+if [ "$DEVCONF" == "static" ]; then
+    if [ -f /etc/usbinput.static ]; then
+        cp -f /etc/usbinput.static /etc/usbinput
+    fi
+fi
 
 # update /etc/usbinput
 /opt/userful/bin/make-config-file -r
 
+#delete lock file
+rm -f $LOCK_FILE
+
 # send signal to X to reopen the input devices
 pkill -USR2 MXSigDaemon
 # send signal to GUI and kbd/mse daemons
